import React from 'react'
import { FluidType } from 'enum/fluid.enum'
import Switch, { SwitchProps } from '@material-ui/core/Switch'
import { withStyles } from '@material-ui/core/styles'

const SwitchBase = withStyles({
  switchBase: {
    color: 'var(--textBright)',
    '&$checked': {
      color: 'var(--textBright)',
      '& + $bar': {
        opacity: 1,
        backgroundColor: 'var(--multiColor)',
      },
    },
  },
  checked: {},
  bar: {
    opacity: 1,
    backgroundColor: 'var(--greyDark)',
  },
})(Switch)

const SwitchElec = withStyles({
  switchBase: {
    '&$checked': {
      '& + $bar': {
        backgroundColor: 'var(--elecColor)',
      },
    },
  },
  checked: {},
  bar: {},
})(SwitchBase)

const SwitchWater = withStyles({
  switchBase: {
    '&$checked': {
      '& + $bar': {
        backgroundColor: 'var(--waterColor)',
      },
    },
  },
  checked: {},
  bar: {},
})(SwitchBase)

const SwitchGas = withStyles({
  switchBase: {
    '&$checked': {
      '& + $bar': {
        backgroundColor: 'var(--gasColor)',
      },
    },
  },
  checked: {},
  bar: {},
})(SwitchBase)

interface StyledSwitchProps extends SwitchProps {
  fluidTypes: FluidType[]
}

const StyledSwitch: React.ComponentType<StyledSwitchProps> = ({
  fluidTypes,
  ...props
}: StyledSwitchProps) => {
  if (fluidTypes.length === 1) {
    switch (fluidTypes[0]) {
      case FluidType.ELECTRICITY:
        return <SwitchElec {...props} />
      case FluidType.WATER:
        return <SwitchWater {...props} />
      case FluidType.GAS:
        return <SwitchGas {...props} />
      default:
        return <SwitchBase {...props} />
    }
  }
  return <SwitchBase {...props} />
}

export default StyledSwitch
