import React, { useState, useEffect } from 'react'
import { withClient, Client } from 'cozy-client'

import { Konnector } from 'doctypes'
import KonnectorService from 'services/konnectorService'

import KonnectorViewerCard from 'components/ContentComponents/KonnectorViewer/KonnectorViewerCard'
import IFluidConfig from 'services/IFluidConfig'

export interface KonnectorViewerProps {
  fluidConfig: IFluidConfig
  client: Client
  isParam: boolean
}

const KonnectorViewer: React.FC<KonnectorViewerProps> = ({
  fluidConfig,
  client,
  isParam = false,
}: KonnectorViewerProps) => {
  const [konnector, setKonnector] = useState<Konnector | null>(null)
  const [loaded, setLoaded] = useState<boolean>(false)

  useEffect(() => {
    let subscribed = true
    const konnectorService = new KonnectorService(
      client,
      fluidConfig.konnectorConfig.slug
    )
    async function getData() {
      const _konnector: Konnector = await konnectorService.fetchKonnector()
      if (subscribed && _konnector) {
        setKonnector(_konnector)
      }
      if (subscribed) {
        setLoaded(true)
      }
    }
    getData()
    return () => {
      subscribed = false
    }
  }, [])

  return (
    <>
      {!loaded ? null : (
        <KonnectorViewerCard
          fluidConfig={fluidConfig}
          konnector={konnector}
          isParam={isParam}
        />
      )}
    </>
  )
}

export default withClient(KonnectorViewer)
